@@ -694,7 +694,7 @@ digitMult(){
     char *pt;
     strcpy(ed, en[wc+1]);
     if(strcmp(ed,"hundred") != 0 && strcmp(ed,"thousand") != 0 &&
-    strcmp(ed,"million") != 0 && strcmp(ed, "billion") != 0){
+       strcmp(ed,"million") != 0 && strcmp(ed, "billion") != 0 && strcmp(ed, "trillion") != 0){
       ct = 0;	return;
     }
     if((pt = (char*)strchr(cj[wc], '.'))){
@@ -706,6 +706,12 @@ digitMult(){
       }
       ptcut(pt, 1);
     }
+    if(strcmp(en[wc+1], "hundred") != 0){
+    if(wc > 0 && strstr(en[wc-1], "ty")){ ct = 0; return; }
+    if(wc > 0 && strstr(en[wc-1], "hundred")){ ct = 0; return; } //18/10/31
+    if(wc > 0 && strcmp(en[wc-1], "and") == 0){ ct = 0; return; } //18/11/18
+    }
+ if(Dbg == 'Y') fprintf(dbg, "--- digitMult --- %s * %s \n", cj[wc], cj[wc+1]);
     strcat(cj[wc], cj[wc+1]+3 + n);
     cj[wc+1][0] = '\0';	ct = 1;
 }
@@ -713,14 +719,48 @@ digitMult(){
 digitAdd(){
     int ln, ln1;
     char ed[WordLen];
- if(Dbg == 'Y') fprintf(dbg, "--- digitAdd --- %s  %s + %s \n", en[wc], cj[wc], cj[wc+2]);
     strcpy(ed, en[wc]);
+    if(strcmp(ed, "twenty") == 0 || strcmp(ed, "thirty") == 0 || strcmp(ed, "fourty") == 0 || strcmp(ed, "fifty") == 0 || strcmp(ed, "sixty") == 0 || strcmp(ed, "seventy") == 0 || strcmp(ed, "eighty") == 0 || strcmp(ed, "ninety") == 0){
+      if(strcmp(en[wc+1], "trillion") == 0){ ct = 0; return; }  //18/11/14
+      if(strcmp(en[wc+1], "billion") == 0){ ct = 0; return; }  //18/11/14
+      if(strcmp(en[wc+1], "million") == 0){ ct = 0; return; }  //18/11/14
+      if(strcmp(en[wc+1], "thousand") == 0){ ct = 0; return; }  //18/11/14
+ if(Dbg == 'Y') fprintf(dbg, "--- digitAdd 2 --- %s  %s + %s \n", en[wc], cj[wc], cj[wc+1]);
+        ln = strlen(cj[wc]);	ln1 = strlen(cj[wc+1])-1;
+        ptreplace(cj[wc]+ln-ln1, ln1, cj[wc+1]+1);
+        cj[wc+1][0] = '\0';	ct = 1;
+      return;
+    }
     if(strstr(ed,"hundred") || strstr(ed,"thousand") || strstr(ed,"million")){
+      if(strcmp(en[wc+1], ",") == 0 && strcmp(en[wc+2], "and") == 0){
+      ln = strlen(cj[wc]);	ln1 = strlen(cj[wc+3])-1;
+      ptreplace(cj[wc]+ln-ln1, ln1, cj[wc+3]+1);
+      cj[wc+2][0] = '\0';  cj[wc+3][0] = '\0';	ct = 1;
+      return;
+      }
+    }
+    if(strstr(ed,"hundred") || strstr(ed,"thousand") || strstr(ed,"million")){
+      if(strcmp(en[wc+1], "and") == 0 || strcmp(en[wc+1], ",") == 0){
+ if(Dbg == 'Y') fprintf(dbg, "--- digitAdd --- %s  %s + %s \n", en[wc], cj[wc], cj[wc+2]);
       ln = strlen(cj[wc]);	ln1 = strlen(cj[wc+2])-1;
       ptreplace(cj[wc]+ln-ln1, ln1, cj[wc+2]+1);
       cj[wc+2][0] = '\0';	ct = 1;
+      } else {
+	if(strcmp(en[wc+1], "trillion") == 0){ ct = 0; return; }  //18/11/14
+	if(strcmp(en[wc+1], "billion") == 0){ ct = 0; return; }  //18/11/7
+	if(strcmp(en[wc+1], "million") == 0){ ct = 0; return; }  //18/11/7
+	if(strcmp(en[wc+1], "thousand") == 0){ ct = 0; return; }  //18/10/29
+	if(strstr(en[wc-1], "ty")){ ct = 0; return; }  //18/10/28
+	if(strcmp(en[wc+2], "hundred") == 0){ ct = 0; return; }  //18/10/29
+ if(Dbg == 'Y') fprintf(dbg, "--- digitAdd 1 --- %s  %s + %s \n", en[wc], cj[wc], cj[wc+1]);
+        ln = strlen(cj[wc]);	ln1 = strlen(cj[wc+1])-1;
+        ptreplace(cj[wc]+ln-ln1, ln1, cj[wc+1]+1);
+        cj[wc+1][0] = '\0';	ct = 1;
+      }
+      return;  //
     }
-    else ct = 0;
+    //else ct = 0;
+    ct = 0;  //
 }
 
 bpoKisok(ume)
