@@ -130,13 +130,16 @@ char *argv[];
     printf("\n");	puts(egs);
     printf("--------------------------------------------\n");
     puts(jps);	fprintf(fpout, "%s", jps);
-    if(LOG == 'Y') fprintf(prcs, "%s \n", jps);
+    if(LOG == 'Y'){ fprintf(prcs, "%s \n", jps);
+    }
     if(quo == 0 && script == 0 && *jps != '<') fprintf(fpout, "\n");
     if(buf[0] == ';' || buf[0] == ',') goto mai1;
     goto mai1;
   MAI2:
     printf("End of file reached\n");
-    if(LOG == 'Y') fclose(prcs);
+    if(LOG == 'Y'){ fclose(prcs);
+      system("nkf --windows --overwrite PROCESS.YAK");
+    }
     if(Dbg == 'Y'){ fclose(dbg); fclose(wdr);    }
     fclose(fpin);	fclose(fpout);	fclose(ejd);
     if(existence == 0){ printf("Sentence not exist!\n");  exit(1); }
