@@ -49,7 +49,7 @@ char go_a[][11] = {"Ȃ","","","","","Ȃ","","˂",""}; // 9
 //  ȂȂȂ
 char go_i[][11] = {"܂","","","","܂",
                    "","܂","ςȂ","","₷",
-                   "","ɂ","˂","","",
+                   "","ɂ","","","",
                    "","͂","","","","","","o","","","A"}; // 26 ܂
 char go_e[][11] = {"","","Ȃ","Ȃ","","","܂","Ă","B","v"}; // 10  Kp
 char gz_e[][ 5] = {"\0","|","|","|","|","|","|","|","|","|"}; // 10 i͓Kp
@@ -59,10 +59,10 @@ char kako[][5] = {"","","","","",""}; // 6
 char site[][5] = {"","","","","",""};
 char genz[][3] = {"","","","","",""};
 
-char ke_i[][11] = {"낤","","",""}; // 4
+char ke_i[][11] = {"낤","","","A"}; // 4
 char keDa[][11] = {"낤","ł","ɂ","ɂ","ɂ",""}; // 6
 
-char *genSkip8 = "ɂ,Ƃ,オ,낦,悤ɂ,ߖ,܂,炩,΂,̂߂,||,낤,C^r,Ƃ͂,g,ڂW,߂,F,ɂĂ,vƂ";
+char *genSkip8 = "ɂ,Ƃ,オ,낦,悤ɂ,ߖ,܂,炩,΂,̂߂,||,낤,C^r,Ƃ͂,g,ڂW,߂,F,ɂĂ,vƂ,";
 char *genSkip6 = "ύX,,b,,M,],΂ߏ,ʂ,Ȃ,܂,ɂ,,߂,lC,,₦,v`,v,,Ȃ,ɂ͂,E,₢,mb,[,,S,c_,肵,F肵,ᔽ,,Ƃ,y,O,\\,S,A,,A";
 
 // 
@@ -710,7 +710,10 @@ char *jpw, *hinsi;
       strncpy(gokan, jpw, ln-2);  gokan[ln-2] = '\0';
       if(strncmp(wdw, gokan, ln-2) == 0){ // Ov
  if(Dbg == 'Y') fprintf(dbg, "--- keiyoKatsu --- jpw = %s gokan = %s wdw = %s \n", jpw, gokan, wdw);
-       if(strncmp(wdw+ln-2, "", 6) == 0 // 
+        if(strncmp(wdw+ln-2, "", 2) == 0){
+          yn = 1; return(yn);
+        }
+        if(strncmp(wdw+ln-2, "", 6) == 0 // 
         || strncmp(wdw+ln-2, "肵", 6) == 0){ // 肵
 	      ptreplace(wdw+ln-2, 6, "");
 	      strcat(zkc, "p");  yn = 1;
@@ -731,6 +734,9 @@ char *jpw, *hinsi;
       strncpy(gokan, jpw, ln-2);  gokan[ln-2] = '\0';
       if(strncmp(wdw, gokan, ln-2) == 0){ // Ov
  if(Dbg == 'Y') fprintf(dbg, "--- keiyoKatsu --- jpw = %s gokan = %s wdw = %s \n", jpw, gokan, wdw);
+        if(strncmp(wdw+ln-2, "", 2) == 0){
+          yn = 1; return(yn);
+        }
 	// Â Â낤 ͎
 
 	if(strncmp(wdw+ln-2, "", 6) == 0 ){
@@ -1097,7 +1103,7 @@ int desumasu_ck()
       strcpy(wdx, "(exit)");
       return 1;
     }
-    if(strncmp(wdw, "Ƃ", 10) == 0){
+    /*  if(strncmp(wdw, "Ƃ", 10) == 0){
       if(strncmp(wdw, "Ƃ", 12) == 0) return 0;
       ptcut(wdw, 10);
       strcpy(wdh, wdw);
@@ -1107,7 +1113,7 @@ int desumasu_ck()
       }
       strcpy(wdx, "(exit)");
       return 1;
-    }
+    }*/
     if(strncmp(wdw, "Ƃ܂", 14) == 0){
       ptcut(wdw, 14);
       strcpy(wdh, wdw);
@@ -1187,7 +1193,12 @@ int  ppt;
 	// if(Dbg == 'Y') fprintf(dbg, "--- diclook --- nx = %d jpw = %s wdw = %s \n", nx, jpw, wdw);
 	// `Ap̎AP͍̗pȂ
 	if(ct < 2 && strlen(jpw) == 2) goto NTT;
+
+	*hinsi = *(jw+1);   // i 18/10/16
+        if(ct == 0 && fukugoCk(jpw, hinsi)) goto DICLOOK; 
+
         if(ct == 1 && strncmp(wdw, jpw, strlen((char*)jpw)) != 0){ // 16/4/20
+	DICLOOK:
 	  hinsi[0] = *(jw+1);  hinsi[1] = '\0';
 	  if(strchr("345", *hinsi)){ //  `
 	  // if(Dbg == 'Y') fprintf(dbg, "--- diclook % --- jpw = %s jew = %s \n", jpw, jew);
@@ -1198,14 +1209,15 @@ int  ppt;
 	}
 
 	// `̎̕uv`uv̎ATϊp uv`uAv̎Aiܒi
+	if(strcmp(wdw, jpw) == 0) goto DICL;  // ŏI 18/10/6
 	if(strncmp(wdw+strlen(jpw), "Ȃ", 4) == 0);  // 16/10/15
 	else                                           // 16/10/15
 	strncpy(chr, wdw+strlen(jpw), 2); chr[2] = '\0';
 	if(ct == 0 && (*(jw+1) == '1' || *(jw+1) == '5') &&
 	strstr("ĂȂ܂A", chr)) goto NTT;
-	// Ŏn܂镡̏ꍇ
-	if(ct == 0 && ptncmp(genSkip8, wdw, 8)) goto NTT;
-	if(ct == 0 && ptncmp(genSkip6, wdw, 6)) goto NTT;
+	// ()Ŏn܂镡̏ꍇ
+	//	if(ct == 0 && ptncmp(genSkip8, wdw, 8)) goto NTT;
+	//	if(ct == 0 && ptncmp(genSkip6, wdw, 6)) goto NTT;
 	if( strncmp(wdw, jpw, strlen(jpw)) != 0) goto NTT; // 16/4/20
 
       DICL:
@@ -1224,6 +1236,34 @@ int  ppt;
     }
 }
 
+// p`ۂ
+fukugoCk(jpw, hinsi)
+char *jpw, *hinsi;
+{
+    int ln;
+
+    ln = strlen(jpw);
+    if(ln < 4) return(0);
+
+    if(strlen(jpw) >= 6 && strncmp(wdw, jpw, ln-2) == 0 && strncmp(wdw, jpw, ln) != 0 ){  // ꊲ݈̂v
+ if(Dbg == 'Y') fprintf(dbg, "--- fukugoCk --- jpw = %s \n", jpw);
+      return(1);
+    }
+    if(strlen(jpw) >= 8 && strncmp(wdw, jpw, ln-4) == 0 && strcmp(jpw+ln-4,"") == 0){  // ꊲv T
+      if(strncmp(wdw, jpw, ln) == 0) return(0); // wdw`̏ꍇ
+ if(Dbg == 'Y') fprintf(dbg, "--- fukugoCk --- jpw = %s \n", jpw);
+      return(1);
+    }
+    if(strlen(jpw) >= 4 && strncmp(wdw, jpw, ln-2) == 0 && (strcmp(jpw+ln-2, "") == 0 || strcmp(jpw+ln-2, "") == 0) ){  // ꊲ݈̂v `e
+      if(*hinsi != '5') return(0);
+      //      if(strcmp(jpw, "") == 0) return(0);
+      //      if(strcmp(jpw+ln-4, "") == 0) return(0);
+ if(Dbg == 'Y') fprintf(dbg, "--- fukugoCk --- jpw = %s \n", jpw);
+      return(1);
+    }
+    return(0);
+}
+
 int ptcal(unsigned char *buf)
 {
     int  ppt;
