@@ -2,7 +2,7 @@
 #define	WordNumb	70
 #define SentLen		400
 #define JSentLen	420
-#define WordLen		45
+#define WordLen		90    //45
 #define JWordLen	50
 #define ZokuLen		40
 #define YakugoMax	8
